# Model Interpretation using SHAP

The aim of this module is providing tools for model interpretation using [SHAP](https://shap.readthedocs.io/en/latest/) library.
The class below is a convenience wrapper, that implements multiple plots for tree-based models.

::: probatus.interpret.model_interpret
